@@ -1,14 +1,17 @@
 #!/usr/bin/python3
-# Copyright (c) 2017 David Steele <dsteele@gmail.com>
+# Copyright (c) 2017-2019 David Steele <dsteele@gmail.com>
 #
-# SPDX-License-Identifier: GPL-2+
+# SPDX-License-Identifier: GPL-2.0-or-later
 # License-Filename: LICENSE
 
+import logging
 import subprocess
 import re
 from multiprocessing import Process, Queue
 
 
+log = logging.getLogger("comitup")
+
 # NetworkManager is doing a poor job of maintaining the AP scan list when
 # in AP mode. Use the 'iw' command to get the AP list.
 
@@ -25,6 +28,7 @@ def docmd(cmd):
 
 def devlist():
     """Get a list of supported devices from 'iw'"""
+    log.debug("Getting device list from 'iw'")
     out = docmd("iw dev")
     devs = [x.split()[1] for x in out.split('\n') if "Interface" in x]
     return devs
@@ -46,12 +50,14 @@ def dbm2pct(dbm):
     return str(pct)
 
 
-def devaps(dev):
+def devaps(dev, dump=""):
     """Get a list of Access Points (as dicts) for a device"""
-    out = docmd('iw dev %s scan' % dev)
+    if not dump:
+        log.debug("Getting AP list from 'iw' dev %s" % dev)
+        dump = docmd('iw dev %s scan' % dev)
 
     aps = []
-    for blk in re.split('\nBSS ', out[4:]):
+    for blk in re.split('\nBSS ', dump[4:]):
         try:
             ap = blk2dict(blk)
             ap['power'] = dbm2pct(float(ap['signal'].split()[0]))
@@ -63,8 +69,8 @@ def devaps(dev):
     return aps
 
 
-def apgen(dev, q):
-    for ap in devaps(dev):
+def apgen(dev, q, dump=""):
+    for ap in devaps(dev, dump):
         pt = {}
         pt['ssid'] = ap['SSID']
         pt['strength'] = ap['power']
@@ -121,6 +127,7 @@ def candidates(device=None):
 def ap_conn_count():
     count = 0
     for dev in devlist():
+        log.debug("Getting iw station dump")
         out = docmd('iw dev %s station dump' % dev)
         count += len([x for x in out.split('\n') if "Station" in x])
 
@@ -131,3 +138,9 @@ if __name__ == '__main__':
     print(candidates())
 
     print(ap_conn_count())
+
+    import sys
+    #print(devaps(sys.argv[1], sys.stdin.read()))
+
+    for ap in devaps(sys.argv[1], sys.stdin.read()):
+        print(ap["SSID"], ap["RSN"], ap["power"], "RSN" in ap)
