@@ -1,16 +1,16 @@
 #!/usr/bin/python3
-# Copyright (c) 2017 David Steele <dsteele@gmail.com>
+# Copyright (c) 2017-2019 David Steele <dsteele@gmail.com>
 #
-# SPDX-License-Identifier: GPL-2+
+# SPDX-License-Identifier: GPL-2.0-or-later
 # License-Filename: LICENSE
 
 
 from collections import namedtuple
-import textwrap
 import logging
-import subprocess
-import re
 import os
+import re
+import subprocess
+import textwrap
 
 
 log = logging.getLogger('comitup')
@@ -24,7 +24,7 @@ class DevInfo(object):
                 path = "/sys/class/net/{}/phy80211/name".format(dev)
                 with open(path, 'r') as fp:
                     phy = fp.read().strip()
-                self.dev_list.append( (dev, phy) )
+                self.dev_list.append((dev, phy))
             except FileNotFoundError:
                 pass
 
@@ -37,6 +37,7 @@ class DevInfo(object):
 
 dev_info = DevInfo()
 
+
 def device_present():
     if dev_info.get_devs():
         return None
@@ -62,12 +63,16 @@ def device_supports_ap():
 
 
 def device_nm_managed():
-    devicesinfo = subprocess.check_output("nmcli device show".split(), re.MULTILINE).decode()
+    try:
+        cmd = "nmcli device show"
+        devsinfo = subprocess.check_output(cmd.split(), re.MULTILINE).decode()
 
-    for dev in dev_info.get_devs():
-        if dev not in devicesinfo:
-            # Fail without comment
-            return ""
+        for dev in dev_info.get_devs():
+            if dev not in devsinfo:
+                # Fail without comment
+                return ""
+    except subprocess.CalledProcessError:
+        pass
 
     return None
 
@@ -88,7 +93,7 @@ testspecs = [
         device_supports_ap,
         "comitup-no-ap - The Main wifi device doesn't support AP mode",
         textwrap.dedent("""
-            Comitup uses the first wifi device to implement the comitup-<nnnn>
+            Comitup uses the first wifi device to implement the comitup-<nn>
             Access Point. For this to work, the device must include "AP" in
             list of "Supported interface modes" returned by "iw list".
         """),
